@@ -1,4 +1,5 @@
 import importlib
+import os
 import pkgutil
 import sys
 from functools import reduce, wraps
@@ -10,7 +11,18 @@ from sym.shared.cli.helpers.updater import SymUpdater
 
 
 def is_prod_mode():
-    return not SymUpdater().is_local()
+    return not SymUpdater().is_local() and not _sym_api_url_is_local()
+
+
+def _sym_api_url_is_local():
+    if sym_api_url := os.getenv("SYM_API_URL"):
+        # Local if SYM_API_URL is set and does not point to staging or production.
+        return (
+            sym_api_url != "https://api.staging.symops.com/api/v1"
+            and sym_api_url != "https://api.symops.com/api/v1"
+        )
+
+    return False
 
 
 def import_all(name):
